
NAME
   diff - display line-by-line differences between pairs of text files

SYNOPSIS
   diff	[-abBcdefhHilnNpPqrstTuvwy] [-C lines] [-D name] [-F regexp]
	[-I regexp] [-L from-label [-L to-label]] [-S starting-file] [-U lines]
	[-W columns] [-x pattern] [-X pattern-file]
	[--brief] [--changed-group-format=format] [--context[=lines]] [--ed]
	[--exclude=pattern] [--exclude-from=pattern-file] [--expand-tabs]
	[--forward-ed] [--horizon-lines=lines] [--ifdef=name]
	[--ignore-all-space] [--ignore-blank-lines] [--ignore-case]
	[--ignore-matching-lines=regexp] [--ignore-space-change]
	[--initial-tab] [--label=from-label [--label=to-label]]
	[--left-column] [--minimal] [--new-file] [--new-group-format=format]
	[--new-line-format=format] [--old-group-format=format]
	[--old-line-format=format] [--paginate] [--rcs] [--recursive]
	[--report-identical-files] [--sdiff-merge-assist] [--show-c-function]
	[--show-function-line=regexp] [--side-by-side] [--speed-large-files]
	[--starting-file=starting-file] [--suppress-common-lines] [--text]
	[--unchanged-group-format=format] [--unchanged-line-format=format]
	[--unidirectional-new-file] [--unified[=lines]] [--version]
	[--width=columns] path1 path2

DESCRIPTION
   This manual page is a description of GNU diff 2.5, although it is 
   not the "official" GNU documentation.

   diff is a differential file comparator.  When run on regular files,
   and when comparing text files that differ during directory
   comparison (see the notes below on comparing directories), diff
   tells what lines must be changed in the files to bring them into
   agreement.  Except in rare circumstances, diff finds a smallest
   sufficient set of differences.  If neither path1 nor path2 is a
   directory, either may be given as "-", in which case the standard
   input is used.  If path1 is a directory, a file in that directory
   whose filename is the same as the filename of path2 is used (and
   vice versa).

   There are several options for output format; the default output
   format contains lines of these forms:

      n1
      a
      n3, n4

      n1, n2
      d
      n3

      n1, n2
      c
      n3, n4

   These lines resemble ed(1) commands to convert path1 into path2.
   The numbers after the letters pertain to path2.  In fact, by
   exchanging a for d and reading backward one may ascertain
   equally how to convert path2 into path1.  As in ed(1), identical
   pairs, where n1 = n2 or n3 = n4, are abbreviated as a single
   number.

   Following each of these lines come all the lines that are
   affected in the first file flagged by "<", then all the lines
   that are affected in the second file flagged by ">".

   If both arguments are directories, diff sorts the contents of
   the directories by name, and then runs the regular file diff
   program as described above on text files which are different.
   Binary files which differ, common subdirectories, and files
   which appear in only one directory are listed.

OPTIONS
   Below is a summary of all of the options that GNU 'diff' accepts.  
   Most options have two equivalent names, one of which is a single 
   letter preceded by '-', and the other of which is a long name 
   preceded by '--'.  Multiple single letter options (unless they 
   take an argument) can be combined into a single command line 
   word: '-ac' is equivalent to '-a -c'.  Long named options can be 
   abbreviated to any unique prefix of their name.  Brackets ([ and ]) 
   indicate that an option takes an optional argument.

   -a
   --text
     Treat all files as text and compare them line-by-line, even
     if they do not seem to be text.

   -b
   --ignore-space-change
     Ignore changes in amount of white space.

   -B
   --ignore-blank-lines
     Ignore changes that just insert or delete blank lines.

   -c
     Use the context output format.

   -C lines
   --context[=lines]
     Use the context output format, showing 'lines' (an integer)
     lines of context, or three if 'lines' is not given.  For
     proper operation, 'patch' typically needs at least two lines
     of context.

   --changed-group-format=format
     Use 'format' to output a line group containing differing
     lines from both files in if-then-else format.

   -d
     Change the algorithm perhaps find a smaller set of changes.
     This makes 'diff' slower (sometimes much slower).

   -D name
   --ifdef=name
     Make merged '#ifdef' format output, conditional on the
     preprocessor macro 'name'.

   -e
   --ed
     Make output that is a valid 'ed' script.

   --exclude=pattern
     When comparing directories, ignore files and subdirectories
     whose basenames match 'pattern'.

   --exclude-from=file
     When comparing directories, ignore files and subdirectories
     whose basenames match any pattern contained in 'file'.

   -f
   --forward-ed
     Make output that looks vaguely like an 'ed' script but has
     changes in the order they appear in the file.

   -F regexp
     In context and unified format, for each hunk of differences,
     show some of the last preceding line that matches 'regexp'.

   -h
     This option currently has no effect; it is present for Unix
     compatibility.

   -H
   --speed-large-files
     Use heuristics to speed handling of large files that have
     numerous scattered small changes.

   --horizon-lines=lines
     Do not discard the last 'lines' lines of the common prefix
     and the first 'lines' lines of the common suffix.

   -i
   --ignore-case
     Ignore changes in case; consider upper- and lower-case
     letters equivalent.

   -I regexp
   --ignore-matching-lines=regexp
     Ignore changes that just insert or delete lines that match 
     'regexp'.

   -l
   --paginate
     Pass the output through 'pr' to paginate it.

   -L from [-L to]  
   --label=from [--label=to]
     Use 'from' instead of the file name in the context format 
     and unified format headers.

   --left-column
     Print only the left column of two common lines in side by 
     side format.

   --line-format=format
     Use 'format' to output all input lines in if-then-else 
     format.

   --minimal
     Change the algorithm to perhaps find a smaller set of 
     changes.  This makes 'diff' slower (sometimes much slower).

   -n
   --rcs
     Output RCS-format diffs; like '-f' except that each command 
     specifies the number of lines affected.

   -N
   --new-file
     In directory comparison, if a file is found in only one 
     directory, treat it as present but empty in the other 
     directory.

   --new-group-format=format
     Use 'format' to output a group of lines taken from just the 
     second file in if-then-else format.

   --new-line-format=format
     Use 'format' to output a line taken from just the second 
     file in if-then-else format.

   --old-group-format=format
     Use 'format' to output a group of lines taken from just the 
     first file in if-then-else format.

   --old-line-format=format
     Use 'format' to output a line taken from just the first 
     file in if-then-else format.

   -p
   --show-c-function
     Show which C function each change is in.

   -P
     When comparing directories, if a file appears only in the 
     second directory of the two, treat it as present but empty 
     in the other.

   -q
   --brief
     Report only whether the files differ, not the details of the
     differences.

   -r
   --recursive
     When comparing directories, recursively compare any 
     subdirectories found.

   -s
   --report-identical-files
     Report when two files are the same.

   -S file
   --starting-file=file
     When comparing directories, start with the file 'file'.  
     This is used for resuming an aborted comparison.

   --sdiff-merge-assist
     Print extra information to help 'sdiff'.  'sdiff' uses this 
     option when it runs 'diff'.  This option is not intended for 
     direct use.

   --show-function-line=regexp
     In context and unified format, for each hunk of differences, 
     show some of the last preceding line that matches 'regexp'.


   --suppress-common-lines
     Do not print common lines in side by side format.

   -t
   --expand-tabs
     Expand tabs to spaces in the output, to preserve the
     alignment of tabs in the input files.

   -T
   --initial-tab
     Output a tab rather than a space before the text of a line 
     in normal or context format.  This causes the alignment of 
     tabs in the line to look normal.

   -u
     Use the unified output format.

   --unchanged-group-format=format
     Use 'format' to output a group of common lines taken from 
     both files in if-then-else format.

   --unchanged-line-format=format
     Use 'format' to output a line common to both files in 
     if-then-else format.

   --unidirectional-new-file
     When comparing directories, if a file appears only in the 
     second directory of the two, treat it as present but empty 
     in the other.

   -U lines
   --unified[=lines]
     Use the unified output format, showing 'lines' (an integer) 
     lines of context, or three if 'lines' is not given.  For 
     proper operation, 'patch' typically needs at least two lines 
     of context.

   -v
   --version
     Output the version number of 'diff'.

   -w
   --ignore-all-space
     Ignore white space when comparing lines.

   -W columns
   --width=columns
     Use an output width of 'columns' in side by side format.

   -x pattern
     When comparing directories, ignore files and subdirectories 
     whose basenames match 'pattern'.

   -X file
     When comparing directories, ignore files and subdirectories 
     whose basenames match any pattern contained in 'file'.

   -y
   --side-by-side
     Use the side by side output format.

DIAGNOSTICS
   Exit status is 0 for no differences, 1 for some differences, 2 for
   trouble.

   Missing newline at end of file X
   Indicates that the last line of file 'X' did not have a NEWLINE.  
   If the lines are different, they will be flagged and output, 
   although the output will seem to indicate they are the same.

BUGS
   Editing scripts produced under the -e or -f option are naive about
   creating lines consisting of a single '.'.

   When comparing directories with the -b, -w or -i options specified,
   diff first compares the files (as in cmp(1), and then runs the
   regular diff algorithm if they are not equal.  This may cause a
   small amount of spurious output if the files then turn out to be
   identical because the only differences are insignificant blank
   string or case differences.

   The -D option ignores existing preprocessor controls in the source
   files, and can generate #ifdefs's with overlapping scope.  The
   output should be checked by hand, or run through cc -E (see cc(1V))
   and then diffed with the original source files.  Discrepancies
   revealed should be corrected before compilation.
